@@ -30,10 +30,13 @@
 insert_js_code_for_score_calculation <- function() {
   df <- utils::read.csv(getOption("checkdown.table"), header = TRUE)
   df$rows_id <- seq_along(df$q_id)
-  paste0("function evaluate_final_score(){",
-         paste0("var text, ", paste0("res", df$rows_id, collapse = ", "), ";"),
+  paste0("function evaluate_final_score(){
+         element = document.getElementById('checkdown_final_score');
+         if(element === null){return false;} else {",
+         paste0("var element, text, ", paste0("res", df$rows_id, collapse = ", "), ";"),
          paste0(glue::glue_data(df, "res{rows_id} = document.getElementById('result_{q_id}').innerText == '{right}';"), collapse = " "),
          paste0("text = ", paste0("res", df$rows_id, collapse = " + "), ";"),
-         "document.getElementById('checkdown_final_score').innerHTML = text;
-         return false;}")
+         "element.innerHTML = text;
+         return false;
+         }}")
 }
